@@ -1,5 +1,8 @@
 from dsp_tools.commands.xmlupload.iri_resolver import IriResolver
 from dsp_tools.commands.xmlupload.models.permission import PermissionValue
+from dsp_tools.error.xmllib_errors import XmllibFileNotFoundError
+from dsp_tools.error.xmllib_errors import XmllibInputError
+from dsp_tools.error.xmllib_errors import XmllibInternalError
 from dsp_tools.utils.ansi_colors import BOLD_GREEN
 from dsp_tools.utils.ansi_colors import YELLOW
 from dsp_tools.utils.data_formats.date_util import is_full_date
@@ -22,3 +25,7 @@ is_full_date("")
 check_notna("")
 
 validate_root_emit_user_message()
+
+XmllibInputError()
+XmllibInternalError()
+XmllibFileNotFoundError()
