@@ -7,7 +7,7 @@ from dsp_tools.commands.ingest_xmlupload.upload_files.input_error import FilePro
 
 SUPPORTED_EXTENSIONS = (
     "zip,tar,gz,z,tgz,gzip,7z,mp3,wav,pdf,doc,docx,xls,xlsx,ppt,pptx,epub,"
-    "mp4,jpg,jpeg,jp2,png,tif,tiff,odd,rng,txt,xml,htm,html,xsd,xsl,csv"
+    "mp4,jpg,jpeg,jp2,json,png,tif,tiff,odd,rng,txt,xml,htm,html,xsd,xsl,csv"
 ).split(",")
 
 
