@@ -1,4 +1,3 @@
-import warnings
 from typing import Any
 from typing import cast
 
@@ -6,7 +5,6 @@ from loguru import logger
 
 from dsp_tools.commands.project.models.project_definition import ProjectDefinition
 from dsp_tools.commands.project.models.project_definition import ProjectMetadata
-from dsp_tools.error.custom_warnings import DspToolsUserWarning
 from dsp_tools.error.exceptions import InputError
 
 
@@ -32,8 +30,6 @@ def parse_project_json(
         default_permissions=project_json["project"]["default_permissions"],
         default_permissions_overrule=project_json["project"].get("default_permissions_overrule"),
     )
-    if project_json["project"].get("default_permissions_overrule"):
-        warnings.warn(DspToolsUserWarning("'default_permissions_overrule' is not implemented yet!"))
     all_lists: list[dict[str, Any]] | None = project_json["project"].get("lists")
     all_ontos = _parse_all_ontos(project_json, all_lists)
 
