@@ -33,7 +33,7 @@ class InternalError(BaseError):
             "    - Which command was used.\n"
             "    - If applicable, any files that were used in conjunction with the command.\n"
             "    - A text file with the terminal output copied into.\n"
-            f"   - The log file at {LOGGER_SAVEPATH}.\n"
+            f"    - The log file at {LOGGER_SAVEPATH}.\n"
         )
         match keep_default_msg, custom_msg:
             case False, str():
@@ -107,3 +107,7 @@ class XmlUploadAuthorshipsNotFoundError(BaseError):
 
 class XmlUploadListNodeNotFoundError(BaseError):
     """Class for errors that are raised when a list node does not exist."""
+
+
+class UnknownDOAPException(BaseError):
+    """Class for errors that are raised if a DOAP cannot be parsed"""
