@@ -24,5 +24,7 @@ def api_url(container_ports: ExternalContainerPorts) -> str:
 def test_systematic(api_url: str) -> None:
     file = Path("testdata/xml-data/test-data-systematic.xml")
     creds = ServerCredentials("root@example.com", "test", api_url)
-    no_violations = validate_data(file, creds, ignore_duplicate_files_warning=False, save_graphs=False)
+    no_violations = validate_data(
+        file, creds, ignore_duplicate_files_warning=False, save_graphs=False, skip_ontology_validation=False
+    )
     assert no_violations
