@@ -8,12 +8,15 @@ from dsp_tools.commands.validate_data.models.rdf_like_data import RdfLikeResourc
 from dsp_tools.commands.validate_data.models.rdf_like_data import RdfLikeValue
 from dsp_tools.commands.validate_data.models.rdf_like_data import TripleObjectType
 from dsp_tools.commands.validate_data.models.rdf_like_data import TriplePropertyType
-from dsp_tools.commands.validate_data.prepare_data.get_rdf_like_data import _get_date_str_and_precision
+from dsp_tools.commands.validate_data.prepare_data.get_rdf_like_data import _get_all_stand_off_links
+from dsp_tools.commands.validate_data.prepare_data.get_rdf_like_data import _get_date_str
 from dsp_tools.commands.validate_data.prepare_data.get_rdf_like_data import _get_file_metadata
 from dsp_tools.commands.validate_data.prepare_data.get_rdf_like_data import _get_file_value
+from dsp_tools.commands.validate_data.prepare_data.get_rdf_like_data import _get_link_string_and_triple_object_type
 from dsp_tools.commands.validate_data.prepare_data.get_rdf_like_data import _get_list_value_str
 from dsp_tools.commands.validate_data.prepare_data.get_rdf_like_data import _get_one_resource
 from dsp_tools.commands.validate_data.prepare_data.get_rdf_like_data import _get_one_value
+from dsp_tools.commands.validate_data.prepare_data.get_rdf_like_data import _get_resource_ids_and_iri_strings
 from dsp_tools.commands.validate_data.prepare_data.get_rdf_like_data import _get_xsd_like_dates
 from dsp_tools.commands.validate_data.prepare_data.get_rdf_like_data import get_rdf_like_data
 from dsp_tools.utils.data_formats.date_util import Era
@@ -165,7 +168,7 @@ class TestResource:
         assert rdf_type.object_type == TripleObjectType.IRI
         standoff = next(x for x in result.property_objects if x.property_type == TriplePropertyType.KNORA_STANDOFF_LINK)
         assert standoff.object_value == "link"
-        assert standoff.object_type == TripleObjectType.IRI
+        assert standoff.object_type == TripleObjectType.INTERNAL_ID
         assert len(result.values) == 1
 
 
@@ -238,11 +241,11 @@ class TestValues:
         assert res.knora_type == KnoraValueType.DATE_VALUE
         assert len(res.value_metadata) == 2
         start = next(x for x in res.value_metadata if x.property_type == TriplePropertyType.KNORA_DATE_START)
-        assert start.object_value == "1849"
-        assert start.object_type == TripleObjectType.DATE_YYYY
+        assert start.object_value == "1849-01-01"
+        assert start.object_type == TripleObjectType.DATE_YYYY_MM_DD
         end = next(x for x in res.value_metadata if x.property_type == TriplePropertyType.KNORA_DATE_END)
-        assert end.object_value == "1850"
-        assert end.object_type == TripleObjectType.DATE_YYYY
+        assert end.object_value == "1850-01-01"
+        assert end.object_type == TripleObjectType.DATE_YYYY_MM_DD
 
     def test_get_xsd_like_dates_only_start(self):
         date_str = "GREGORIAN:CE:1800-01-01"
@@ -265,8 +268,8 @@ class TestValues:
         assert start.object_value == "1800-01-01"
         assert start.object_type == TripleObjectType.DATE_YYYY_MM_DD
         assert end.property_type == TriplePropertyType.KNORA_DATE_END
-        assert end.object_value == "1900"
-        assert end.object_type == TripleObjectType.DATE_YYYY
+        assert end.object_value == "1900-01-01"
+        assert end.object_type == TripleObjectType.DATE_YYYY_MM_DD
 
     def test_get_xsd_like_dates_second_era_wrong(self):
         date_str = "GREGORIAN:CE:2000:BCE:1900"
@@ -274,8 +277,8 @@ class TestValues:
         assert len(result) == 1
         start = result.pop(0)
         assert start.property_type == TriplePropertyType.KNORA_DATE_START
-        assert start.object_value == "2000"
-        assert start.object_type == TripleObjectType.DATE_YYYY
+        assert start.object_value == "2000-01-01"
+        assert start.object_type == TripleObjectType.DATE_YYYY_MM_DD
 
     @pytest.mark.parametrize(
         "date",
@@ -289,19 +292,18 @@ class TestValues:
         assert not result
 
     @pytest.mark.parametrize(
-        ("date", "expected_str", "expected_type"),
+        ("date", "expected_str"),
         [
-            (SingleDate(era=None, year=1900, month=10, day=1), "1900-10-01", TripleObjectType.DATE_YYYY_MM_DD),
-            (SingleDate(era=None, year=1900, month=10, day=None), "1900-10", TripleObjectType.DATE_YYYY_MM),
-            (SingleDate(era=None, year=900, month=None, day=None), "0900", TripleObjectType.DATE_YYYY),
-            (SingleDate(era=Era.CE, year=900, month=None, day=None), "0900", TripleObjectType.DATE_YYYY),
-            (SingleDate(era=Era.AD, year=900, month=None, day=None), "0900", TripleObjectType.DATE_YYYY),
+            (SingleDate(era=None, year=1900, month=10, day=1), "1900-10-01"),
+            (SingleDate(era=None, year=1900, month=10, day=None), "1900-10-01"),
+            (SingleDate(era=None, year=900, month=None, day=None), "0900-01-01"),
+            (SingleDate(era=Era.CE, year=900, month=None, day=None), "0900-01-01"),
+            (SingleDate(era=Era.AD, year=900, month=None, day=None), "0900-01-01"),
         ],
     )
-    def test_get_date_str_and_precision(self, date, expected_str, expected_type):
-        result_str, result_type = _get_date_str_and_precision(date)
+    def test_get_date_str(self, date, expected_str):
+        result_str = _get_date_str(date)
         assert result_str == expected_str
-        assert result_type == expected_type
 
     def test_decimal_corr(self):
         val = ParsedValue(HAS_PROP, "1.4", KnoraValueType.DECIMAL_VALUE, None, None)
@@ -512,5 +514,57 @@ def test_get_list_value_str(input_val, expected):
     assert _get_list_value_str(input_val, LIST_LOOKUP) == expected
 
 
+class TestRichtextStandoff:
+    def test_get_all_stand_off_links_no_links(self):
+        val_str = ParsedValue(HAS_PROP, "text", KnoraValueType.RICHTEXT_VALUE, None, None)
+        val_none = ParsedValue(HAS_PROP, None, KnoraValueType.RICHTEXT_VALUE, None, None)
+        result = _get_all_stand_off_links([val_none, val_str])
+        assert not result
+
+    def test_get_all_stand_off_links_(self, richtext_with_standoff, bool_value):
+        result = _get_all_stand_off_links([richtext_with_standoff, richtext_with_standoff, bool_value])
+        assert len(result) == 1
+        prop_obj = result.pop(0)
+        assert prop_obj.property_type == TriplePropertyType.KNORA_STANDOFF_LINK
+        assert prop_obj.object_value == "link"
+        assert prop_obj.object_type == TripleObjectType.INTERNAL_ID
+
+    def test_get_resource_ids_and_iri_strings_none_found(self):
+        txt = "text"
+        result = _get_resource_ids_and_iri_strings(txt)
+        assert not result
+
+    def test_get_resource_ids_and_iri_strings_multiple_found(self):
+        link = "IRI:link:IRI"
+        res_link = "http://rdfh.ch/4123/DiAmYQzQSzC7cdTo6OJMYA"
+        txt = (
+            f'With <a class="salsah-link" href="{link}">link text</a>.'
+            f'Some more text <a class="salsah-link" href="{link}">with the same link</a>.'
+            f'Text with <a class="salsah-link" href="{res_link}"> stand off</a> to resource in DB.'
+            f'Text with an external link: <a href="https://www.google.com/">Google</a>'
+        )
+        result = _get_resource_ids_and_iri_strings(txt)
+        expected = {link, res_link}
+        assert result == expected
+
+    def test_get_link_string_and_triple_object_type_internal_link(self):
+        link = "IRI:link:IRI"
+        link_str, triple_type = _get_link_string_and_triple_object_type(link)
+        assert link_str == "link"
+        assert triple_type == TripleObjectType.INTERNAL_ID
+
+    def test_get_link_string_and_triple_object_type_iri(self):
+        link = "http://rdfh.ch/4123/DiAmYQzQSzC7cdTo6OJMYA"
+        link_str, triple_type = _get_link_string_and_triple_object_type(link)
+        assert link_str == link
+        assert triple_type == TripleObjectType.IRI
+
+    def test_get_link_string_and_triple_object_malformed_content(self):
+        link = "malformed_content"
+        link_str, triple_type = _get_link_string_and_triple_object_type(link)
+        assert link_str == link
+        assert triple_type == TripleObjectType.INTERNAL_ID
+
+
 if __name__ == "__main__":
     pytest.main([__file__])
